@@ -43,12 +43,28 @@ class CheckBoxConfig(PlainBoxConfig):
         help_text=_("Secure ID of the system"),
         validator_list=[config.PatternValidator(SECURE_ID_PATTERN)])
 
+    submit_to_hexr = config.Variable(
+        section="submission",
+        help_text=_("Whether to also send the submission data to HEXR"),
+        kind=bool)
+
+    # TODO: Add a validator to check if email looks fine
+    email_address = config.Variable(
+        section="sru",
+        help_text=_("Email address to log into the Launchpad HWDB"))
+
     # TODO: Add a validator to check if URL looks fine
     c3_url = config.Variable(
         section="sru",
         help_text=_("URL of the certification website"),
         default="https://certification.canonical.com/submissions/submit/")
 
+    # TODO: Add a validator to check if URL looks fine
+    lp_url = config.Variable(
+        section="sru",
+        help_text=_("URL of the launchpad hardware database"),
+        default="https://launchpad.net/+hwdb/+submit")
+
     fallback_file = config.Variable(
         section="sru",
         help_text=_("Location of the fallback file"))
@@ -71,55 +87,3 @@ class CheckBoxConfig(PlainBoxConfig):
                     PlainBoxConfig.Meta.filename_list, (
                         '/etc/xdg/checkbox.conf',
                         os.path.expanduser('~/.config/checkbox.conf')))))
-
-
-class CertificationConfig(CheckBoxConfig):
-    """
-    Configuration for canonical-certification
-    """
-
-    class Meta(CheckBoxConfig.Meta):
-        # TODO: properly depend on xdg and use real code that also handles
-        # XDG_CONFIG_HOME.
-        #
-        # NOTE: filename_list is composed of canonical-certification, checkbox
-        # and plainbox variables, mixed so that:
-        # - canonical-certification takes precedence over checkbox
-        # - checkbox takes precedence over plainbox
-        # - ~/.config takes precedence over /etc
-        filename_list = list(
-            itertools.chain(
-                *zip(
-                    itertools.islice(
-                        CheckBoxConfig.Meta.filename_list, 0, None, 2),
-                    itertools.islice(
-                        CheckBoxConfig.Meta.filename_list, 1, None, 2),
-                    ('/etc/xdg/canonical-certification.conf',
-                        os.path.expanduser(
-                            '~/.config/canonical-certification.conf')))))
-
-
-class CDTSConfig(CheckBoxConfig):
-    """
-    Configuration for canonical-driver-test-suite (CDTS)
-    """
-
-    class Meta(CheckBoxConfig.Meta):
-        # TODO: properly depend on xdg and use real code that also handles
-        # XDG_CONFIG_HOME.
-        #
-        # NOTE: filename_list is composed of canonical-certification, checkbox
-        # and plainbox variables, mixed so that:
-        # - CDTS takes precedence over checkbox
-        # - checkbox takes precedence over plainbox
-        # - ~/.config takes precedence over /etc
-        filename_list = list(
-            itertools.chain(
-                *zip(
-                    itertools.islice(
-                        CheckBoxConfig.Meta.filename_list, 0, None, 2),
-                    itertools.islice(
-                        CheckBoxConfig.Meta.filename_list, 1, None, 2),
-                    ('/etc/xdg/canonical-driver-test-suite.conf',
-                        os.path.expanduser(
-                            '~/.config/canonical-driver-test-suite.conf')))))
